cemento.axioms.modules package — CEMENTO 0.13.0 documentation

Skip to main content
`Ctrl`+`K`

# cemento.axioms.modules package

## Submodules

## cemento.axioms.modules.ms module

class cemento.axioms.modules.ms.MS

  Bases: `DefinedNamespace`

  And: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/And')
  Asymmetric: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Asymmetric')
  DifferentFrom: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/DifferentFrom')
  Functional: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Functional')
  IntroTerm: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/IntroTerm')
  InverseFunctional: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/InverseFunctional')
  Irreflexive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Irreflexive')
  Is: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Is')
  Not: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Not')
  Ontology: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Ontology')
  Or: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Or')
  Reflexive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Reflexive')
  RemoveIterNumber: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/RemoveIterNumber')
  SameAs: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/SameAs')
  Self: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Self')
  Single: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Single')
  Symmetric: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Symmetric')
  Transitive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/Transitive')
  belongsTo: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/belongsTo')
  equivalentTo: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/equivalentTo')
  exactly: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/exactly')
  forWhich: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/forWhich')
  langRange: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/langRange')
  length: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/length')
  max: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/max')
  maxExclusive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/maxExclusive')
  maxInclusive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/maxInclusive')
  maxLength: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/maxLength')
  min: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/min')
  minExclusive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/minExclusive')
  minInclusive: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/minInclusive')
  minLength: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/minLength')
  o: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/o')
  of: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/of')
  onClass: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/onClass')
  onProperty: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/onProperty')
  only: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/only')
  pattern: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/pattern')
  some: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/some')
  subPropertyChain: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/subPropertyChain')
  that: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/that')
  value: URIRef = rdflib.term.URIRef('https://cwrusdle.bitbucket.io/mds/manchester-syntax/value')

## Module contents